full_pass_builder
library
Classes
-
ChildrenGeometriesProvidedBuilder
-
A widget that exposes its layout calculation to an external visitor.
-
ChildrenGeometriesProviderParentData
-
-
ChildrenGeometriesProviderRenderObject
-
-
FullPassBuilder
-
A widget that makes it much easier to create custom layouts. Some of your
layouts might require siblings, or children geometries to be present, but
to get that, you'd usually have to go through all the boilerplate and imperative
code with GlobalKey and
addPostFrameCallback. With this, all you need
is to just invoke the FullPassBuilder constructor, and all the information
you need will just be there for you.
-
Layouter
-
A class that helps manage the positioning of children as well as providing
some vital information obtained during
performLayout
-
OffsetWrapper
-
A wrapper to help set the offset on the parent data